# Python API

Caracal exposes a Python API thanks to [pybind11](https://github.com/pybind/pybind11).
To install these bindings, run:
```bash
pip install pycaracal
```

The API is currently not documented. Please refer to the tests file for usage examples.

```python title="python/tests/test_pycaracal.py"
--8<-- "python/tests/test_pycaracal.py"
```

```python title="python/tests/test_experimental.py"
--8<-- "python/tests/test_experimental.py"
```
